@@ -164,6 +164,10 @@ def load_ValidationStep(data: Dict[str, Any]) -> ValidationStep:
         )
 
 
+def dump_ValidationStep(step: ValidationStep) -> Dict[str, Any]:
+    return validation_step_schema.dump(step)  # type: ignore[no-any-return]
+
+
 validation_result_schema = ValidationResultSchema()
 
 
