@@ -1,4 +1,4 @@
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import logging
 import operator
@@ -21,12 +21,14 @@ def meets_filesize_threshold(
     """Validates whether or not a filepath meets a given filesize threshold.
 
     Args:
-        value: filepath to validate
-        threshold: filesize threshold in bytes
+        value: Filepath to validate.
+        threshold: minimum filesize threshold in bytes
         operator_name: name of which python ``operator`` to use
+
     Returns:
-        filesize: filesize in bytes
-        meets_threshold: whether or not the threshold was met
+        A tuple of length 2 wherein, the first element is the filesize of
+        the `value` and the second element is a boolean whether or not the
+        `threshold` for this value was met.
     """
     op = getattr(operator, operator_name)
     filesize = os.path.getsize(value)
@@ -36,7 +38,7 @@ def meets_filesize_threshold(
     )
 
 
-def has_dict_key(value: dict, path: List[str]) -> Tuple[Any, bool]:  # type: ignore
+def has_dict_key(value: Dict[str, Any], path: List[str]) -> Tuple[Any, bool]:
     """Validates whether or not a dictionary has a key at given paths.
 
     A single element path will grab from the top level keys. Multiple path elements are used to index into nested dictionaries.
@@ -64,7 +66,7 @@ def has_dict_key(value: dict, path: List[str]) -> Tuple[Any, bool]:  # type: ign
 
 
 def meets_value_threshold(
-    value: Union[dict, Dataset],
+    value: Union[Dict[str, Any], Dataset],
     path: List[str],
     threshold: Union[float, int],
     tolerance: Optional[Union[float, int]] = None,
@@ -81,13 +83,16 @@ def meets_value_threshold(
         The indexed value.
         Whether or not the indexed value meets the given `threshold`.
 
+    Raises:
+        Exception: Dataset supplied as `value` and length path > 1.
+        TypeError: Value is an unsupported datatype.
+
     Note:
         To index into nested dict-like objects, use a `path` with length greater than 1.
 
         Dataset targets only support a `path` of length 1.
 
         meant to mirror ``get_data_subtype`` for ``synchronization_data`` in ``NP_pipeline_validation``, an earlier implementation this tool is based off of
-
     """
     if isinstance(value, Dataset):
         if len(path) > 1:
@@ -105,9 +110,10 @@ def meets_value_threshold(
 
     if tolerance is None:
         try:
-            actual_value = len(value)
+            # this is the way the legacy code worked, dont want new bugs
+            actual_value = len(value)  # type: ignore[arg-type]
         except TypeError as E:
-            actual_value = value
+            actual_value = value  # type: ignore[assignment]
     else:
         actual_value = rate(value)
 
